@@ -11,6 +11,7 @@
 
 #include "gamgi_engine.h"
 #include "gamgi_mesa.h"
+#include "gamgi_io.h"
 
 #include "gamgi_math_vector.h"
 #include "gamgi_math_matrix.h"
@@ -306,6 +307,8 @@ plane_new->blue = plane->blue;
 
 void gamgi_engine_copy_out_group (gamgi_group *group, gamgi_group *group_new)
 {
+int i;
+
 static_copy (GAMGI_CAST_OBJECT group, GAMGI_CAST_OBJECT group_new);
 group_new->draw = group->draw;
 
@@ -325,6 +328,41 @@ group_new->quaternion[0] = group->quaternion[0];
 group_new->quaternion[1] = group->quaternion[1];
 group_new->quaternion[2] = group->quaternion[2];
 group_new->quaternion[3] = group->quaternion[3];
+
+/**************************************
+ * copy arrays: points, loops, colors *
+ **************************************/
+
+group_new->points = NULL;
+i = 3 * group->n_points;
+if (i > 0) group_new->points = (double *) malloc (sizeof (double) * i);
+while (i-- > 0) group_new->points[i] = group->points[i];
+
+group_new->loops = NULL;
+i = group->n_loops;
+if (i > 0) group_new->loops = (int *) malloc (sizeof (int) * i);
+while (i-- > 0) group_new->loops[i] = group->loops[i];
+
+/****************************************
+ * copy number of points, loops, colors *
+ ****************************************/
+
+group_new->n_points = group->n_points;
+group_new->n_loops = group->n_loops;
+
+/************************
+ * copy hide/show flags *
+ ************************/
+
+group_new->faces = group->faces;
+
+/**************************
+ * copy color information *
+ **************************/
+
+group_new->red = group->red;
+group_new->green = group->green;
+group_new->blue = group->blue;
 }
 
 void gamgi_engine_copy_out_molecule (gamgi_molecule *molecule, gamgi_molecule *molecule_new)
