@@ -325,6 +325,14 @@ group->quaternion[2] = 0.0;
 group->quaternion[3] = 1.0;
 
 group->draw = NULL;
+
+group->points = NULL;
+group->loops = NULL;
+
+group->n_points = 0;
+group->n_loops = 0;
+
+group->faces = FALSE;
 }
 
 /******* external function ******
