@@ -957,6 +957,9 @@ if (window->action == GAMGI_GTK_CLUSTER_MEASURE)
 dialog = gamgi_gtk_dialog_report_create (text, 
 "Measure Voronoi", action, window);
 
+printf ("2: %f %f %f\n", cluster->origin[0], cluster->origin[1], cluster->origin[2]);
+fflush (stdout);
+
 gtk_widget_show (dialog);
 }
 
