@@ -100,8 +100,8 @@ GAMGI_IO_VERA_MONO_ITALIC, GAMGI_IO_VERA_MONO_BOLD_ITALIC };
  * the Gamgi->About GUI dialog *
  *******************************/
 
-#define GAMGI_IO_DATE "3th August 2008"
-#define GAMGI_IO_VERSION "0.13.8"
+#define GAMGI_IO_DATE "7th January 2009"
+#define GAMGI_IO_VERSION "0.13.10"
 #define GAMGI_IO_AUTHORS "Carlos Pereira"
 #define GAMGI_IO_LICENSE "GPL"
 #define GAMGI_IO_WEBSITE "http://www.gamgi.org/"
