@@ -553,14 +553,6 @@ else
   return gamgi_io_file_local (fullname, filename, parser, window, data);
 }
 
-/***************************************************************
- *          Copyright (c) Mark J. Kilgard, 1996.               *
- *                                                             *
- * This program is freely distributable without licensing fees *
- * and is provided without guarantee or warrantee expressed or *
- * implied. This program is -not- in the public domain.        *
- ***************************************************************/
-
 gamgi_bool gamgi_io_file_export_ps (FILE *fp,
 int width, int height, gamgi_bool *error)
 {
@@ -575,73 +567,56 @@ char string[GAMGI_ENGINE_LINE];
 components = 3;
 pixels = gamgi_mesa_area_grab (0, 0, width, height);
 
-/****************
- * write header *
- ****************/
+/***********************************************************
+ * Write header, adapted from: 1) the header produced      *
+ * by Gimp 2.4.6 when exporting .eps encapsulated          *
+ * postcript files (without level 2), written by Peter     *
+ * Kirchgessner; 2) the book Postcript Language, Tutorial  *
+ * and Cookbook, Adobe Systems Inc., Addison-Wesley, 1986  *
+ ***********************************************************/
 
 gamgi_io_file_fprintf (fp, "%!PS-Adobe-3.0 EPSF-3.0\n", error);
-
 sprintf (string, "%%%%Creator: GAMGI %s\n", GAMGI_IO_VERSION);
 gamgi_io_file_fprintf (fp, string, error);
-
 gamgi_io_file_fprintf (fp, "%%DocumentData: Clean7Bit\n", error);
-
 gamgi_io_file_fprintf (fp, "%%LanguageLevel: 2\n", error);
-
-gamgi_io_file_fprintf (fp, "%%Pages: 0\n", error);
-
+gamgi_io_file_fprintf (fp, "%%Pages: 1\n", error);
 sprintf (string, "%%%%BoundingBox: 0 0 %d %d\n", width, height);
 gamgi_io_file_fprintf (fp, string, error);
-
 gamgi_io_file_fprintf (fp, "%%EndComments\n", error);
-
-gamgi_io_file_fprintf (fp, "gsave\n", error);
-
-gamgi_io_file_fprintf (fp, "systemdict /colorimage known not\n", error);
-
-gamgi_io_file_fprintf (fp, "{ /colorimage pop pop def } if\n", error);
 sprintf (string, "/scanline %d string def\n", width * components);
-
 gamgi_io_file_fprintf (fp, string, error);
-
 sprintf (string, "%d %d scale\n", width, height);
 gamgi_io_file_fprintf (fp, string, error);
-
 sprintf (string, "%d %d %d\n", width, height, 8);
 gamgi_io_file_fprintf (fp, string, error);
-
 sprintf (string, "[%d 0 0 %d 0 0]\n", width, height);
 gamgi_io_file_fprintf (fp, string, error);
-
 gamgi_io_file_fprintf (fp, "{currentfile scanline readhexstring pop}\n", error);
-
 sprintf (string, "false %d\n", components);
 gamgi_io_file_fprintf (fp, string, error);
-
 gamgi_io_file_fprintf (fp, "colorimage\n", error);
 
-/**************
- * write data *
- **************/
+/********************************************
+ * Write data: adapted from the book OpenGL *
+ * Programming for the X Window System p98, *
+ * Mark J. Kilgard, Addison-Wesley, 1996.   *
+ ********************************************/
 
 i = 0;
 while (i < width * height * components)
   {
-  sprintf (string, "%02hx", pixels[i++]);
+  sprintf (string, "%02x", pixels[i++]);
   gamgi_io_file_fprintf (fp, string, error);
-
-  if (i % 32 == 0)
-    gamgi_io_file_fprintf (fp, "\n", error);
+  if (i % 40 == 0) gamgi_io_file_fprintf (fp, "\n", error);
   }
+if (i % 40 != 0) gamgi_io_file_fprintf (fp, "\n", error);
 
-if (i % 32 != 0)
-  gamgi_io_file_fprintf (fp, "\n", error);
-gamgi_io_file_fprintf (fp, "grestore\n", error);
-
-/******************
- * free resources *
- ******************/
-
+/*******************************************
+ * show postscript page and free resources *
+ *******************************************/
+ 
+gamgi_io_file_fprintf (fp, "showpage\n", error);
 free (pixels);
 
 return TRUE;
@@ -869,7 +844,7 @@ else if (strcmp (extension, "jpeg") == 0 || strcmp (extension, "jpg") == 0)
   gamgi_io_file_export_jpeg (fullname, fp, width, height, &error);
 else if (strcmp (extension, "png") == 0)
   gamgi_io_file_export_png (fullname, fp, width, height, &error);
-else if (strcmp (extension, "ps") == 0)
+else if (strcmp (extension, "eps") == 0 || strcmp (extension, "ps") == 0)
   gamgi_io_file_export_ps (fp, width, height, &error);
 else if (strcmp (extension, "ppm") == 0)
   gamgi_io_file_export_ppm (fp, width, height, &error);
