@@ -8,7 +8,6 @@
  * General Public License: $GAMGI/LICENSE
  *
  */
-
 #include "gamgi_engine.h"
 #include "gamgi_gtk.h"
 #include "gamgi_mesa.h"
@@ -188,6 +187,8 @@ glTranslatef (-center[0], -center[1], -center[2]);
 if (bond->first == TRUE) bond->first = FALSE;
 else
   {
+  bond->first = TRUE;
+
   /*********************
    * draw orbital list *
    *********************/
@@ -205,8 +206,6 @@ else
   while (dlist != NULL)
     { gamgi_mesa_draw_text (GAMGI_CAST_TEXT dlist->data);
       dlist = dlist->next; }
-  
-  bond->first = TRUE;
   }
 
 glPopMatrix ();
@@ -440,18 +439,53 @@ glPopMatrix ();
 void gamgi_mesa_draw_group (gamgi_group *group) 
 {
 gamgi_dlist *dlist;
-double origin[3];
+double rotate[16];
+float background[4];
 
 glPushMatrix ();
 
-/******************************
- * get group geometric center *
- ******************************/
-
-gamgi_math_vector_absolute (origin, 0.0, 0.0, 0.0);
-glTranslatef (origin[0], origin[1], origin[2]);
+glTranslatef (group->center[0], group->center[1], group->center[2]);
 glScalef (group->object.scale, group->object.scale, group->object.scale);
-glTranslatef (-origin[0], -origin[1], -origin[2]);
+glTranslatef (-group->center[0], -group->center[1], -group->center[2]);
+
+glPushMatrix ();
+
+glTranslatef (group->origin[0], group->origin[1], group->origin[2]);
+
+gamgi_math_quaternion_to_matrix4 (group->quaternion, rotate);
+glMultMatrixd (rotate);
+
+if (group->loops != NULL)
+  {
+  glLineWidth (GAMGI_MESA_CLUSTER_WIDTH);
+  glPointSize (GAMGI_MESA_CLUSTER_WIDTH);
+
+  glColor3f (group->red, group->green, group->blue);
+
+  if (group->faces == TRUE)
+    {
+    glEnable (GL_POLYGON_OFFSET_FILL);
+    glPolygonOffset (1, 1);
+
+    glPolygonMode (GL_FRONT, GL_FILL);
+    glDisable(GL_CULL_FACE);
+
+    gamgi_mesa_render_polygons (group->loops, group->points);
+
+    glEnable(GL_CULL_FACE);
+
+    glGetFloatv (GL_COLOR_CLEAR_VALUE, background);
+    glColor3fv (background);
+    }
+
+  gamgi_mesa_render_loops (group->loops, group->points);
+
+  glDisable (GL_POLYGON_OFFSET_FILL);
+  glLineWidth (1.0);
+  glPointSize (1.0);
+  }
+
+glPopMatrix ();
 
 /* draw group list */
 dlist = group->group_start;
