@@ -9,6 +9,83 @@
  *
  */
 
+/*
+ * OGLFT: A library for drawing text with OpenGL using the FreeType library
+ * Copyright (C) 2002 lignum Computing, Inc.
+ * Author: Allen Barnett
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+/**************************************
+ * Code taken from: library OGLFT-0.9 *
+ *                                    *
+ *  Functions with GLE code:          *
+ *  gamgi_mesa_text_horizontal_move   *
+ *  gamgi_mesa_text_horizontal_line   *
+ *  gamgi_mesa_text_horizontal_conic  *
+ *  gamgi_mesa_text_horizontal_cubic  *
+ *  gamgi_mesa_text_vertical_move     *
+ *  gamgi_mesa_text_vertical_line     *
+ *  gamgi_mesa_text_vertical_conic    *
+ *  gamgi_mesa_text_vertical_cubic    *
+ *  static_glu_begin                  *
+ *  static_glu_vertex                 *
+ *  static_glu_end                    *
+ *  static_glu_combine                *
+ *  static_glu_error                  *
+ *  static_face                       *
+ *  static_compile_solid              *
+ *  static_extruded_create            *
+ *  static_extruded_remove            *
+ *  static_center_solid               *
+ *                                    *
+ * Code taken by: Carlos Pereira      *
+ **************************************/
+
+/*
+ * GLE: The Tubing and Extrusion Library
+ * Copyright (C) 1991,1994,2003 Linas Vepstas
+ *
+ * The GLE library is distributed under two licenses:
+ * GNU General Public License (GPL) and Public Domain
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ */
+
+/*********************************************
+ * Code taken from the library: GLE-3.1.0    *
+ *                                           *
+ * Functions with GLE code: static_extrusion *
+ *                                           *
+ * Code taken by: Carlos Pereira             *
+ *********************************************/
+
 #include "gamgi_engine.h"
 #include "gamgi_mesa.h"
 #include "gamgi_io.h"
@@ -21,6 +98,9 @@
 #include "gamgi_io_font_sun.h"
 #include "gamgi_io_font_hershey.h"
 
+void static_extrusion (int n_contour, double *contour, double *normals,
+double scale);
+
 void gamgi_mesa_text_data_wired (gamgi_enum font,
 const float **points, const int **driver)
 {
@@ -195,202 +275,7 @@ free (gamgi->glyphs);
 free (gamgi->n_glyphs);
 }
 
-/*
- * GLE: The Tubing and Extrusion Library
- * Copyright (C) 1991,1994,2003 Linas Vepstas
- *
- * SOFTWARE AGREEMENT
- * 
- * PLEASE READ THIS AGREEMENT CAREFULLY BEFORE INSTALLING OR USING THIS
- * SOFTWARE.  IF YOU INSTALL OR USE THIS SOFTWARE, YOU AGREE TO THESE
- * TERMS.
- * 
- * This software is owned by International Business Machines Corporation
- * ("IBM"), or its subsidiaries or IBM's suppliers, and is copyrighted and
- * licensed, not sold.  IBM retains title to the software, and grants you a
- * nonexclusive license for the software.
- * 
- * Under this license, you may:
- * 
- * 1) use the software on one or more machines at a time;
- * 2) make copies of the software for use or backup purposes within your
- *    enterprise;
- * 3) modify this software and merge it with another program; and
- * 4) make copies of the original file you downloaded and distribute it,
- *    provided that you transfer a copy of this license to the other party.
- *    The other party agrees to these terms by its first use of this software.
- * 
- * You must reproduce the copyright notice and any other legend of
- * ownership on each copy or partial copy of the software.
- * 
- * This software, as provided by IBM, is only intended to assist in the
- * development of a working software program. The software may not function
- * as written: additional code is required. In addition, the software may
- * not compile and/or bind successfully as written.
- * 
- * IBM PROVIDES THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
- * EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK
- * AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH YOU.  SHOULD
- * ANY PART OF THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE ENTIRE COST OF
- * ALL NECESSARY SERVICING, REPAIR OR CORRECTION. IN NO EVENT, UNLESS
- * REQUIRED BY APPLICABLE LAW, SHALL IBM BE LIABLE TO YOU FOR DAMAGES,
- * INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES
- * ARISING OUT OF THE USE OR INABILITY TO USE THE SOFTWARE (INCLUDING BUT
- * NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES
- * SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE SOFTWARE TO
- * OPERATE WITH ANY OTHER PROGRAMS), EVEN IF IBM HAS BEEN ADVISED IN
- * ADVANCE OF THE POSSIBILITY OF SUCH DAMAGES.
- * 
- * IBM does not warrant that the contents of the software will meet your
- * requirements, that the software is error-free or that the software does
- * not infringe on any intellectual property rights of any third party.
- * 
- * IBM may make improvements and/or changes in the software at any time.
- * 
- * Changes may or may not be made periodically to the information in the
- * software; these changes may be reported, for the software included
- * herein, in new editions.
- * 
- * References, if any, in the software to IBM products, programs, or
- * services do not imply that IBM intends to make these available in all
- * countries in which IBM operates. Any reference to an IBM licensed
- * program in the software is not intended to state or imply that only
- * IBM's licensed program may be used. Any functionally equivalent program
- * may be used.
- * 
- * The laws of New York State govern this agreement.
- */
-
-/*****************************************
- * Code taken from the library GLE-3.1.0 *
- *                        Carlos Pereira *
- *****************************************/
-
-/*****************************************************
- * This routine draws extrusions with square ends,   *
- * cut at 90 degrees to the length of the extrusion. *
- *****************************************************/
-
-void static_extrusion (int n_contour, double *contour, double *normals, 
-double scale)
-{
-int i;
-double point[3]; 
-double norm[3]; 
-double depth;
-
-/**************************************************************
- * the glyph z coordinate ranges between -depth/2 and depth/2 *
- *                                                            *
- *  z coordinates are independent of the face units per EM    *
- **************************************************************/
-
-depth = GAMGI_MESA_EXTRUDED_DEPTH * GAMGI_MESA_EXTRUDED_SCALE;
-
-/**********************
- * save graphic state *
- **********************/
-
-glPushMatrix ();
-
-/***************************************
- * draw all the lateral segments and   *
- * connect back with the first segment *
- ***************************************/
-
-norm [2] = 0.0;
-glBegin (GL_TRIANGLE_STRIP);
-for (i = 0; i <= n_contour; i++)
-  {
-  if (i == n_contour) i = n_contour = 0;
-
-  norm [0] = normals[2*i + 0];
-  norm [1] = normals[2*i + 1];
-  gamgi_math_vector_normal (norm);
-  glNormal3dv (norm);
-
-  point [0] = contour[2*i + 0] * scale;
-  point [1] = contour[2*i + 1] * scale;
-  point [2] = -depth / 2.0;
-  glVertex3dv (point);
-
-  point [2] = depth / 2.0;
-  glVertex3dv (point);
-  }
-glEnd ();
-
-/**********************************
- * restore previous graphic state *
- **********************************/
-
-glPopMatrix ();
-}
-
-/*
- * OGLFT: A library for drawing text with OpenGL using the FreeType library
- * Copyright (C) 2002 lignum Computing, Inc. 
- * Author: Allen Barnett 
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */
-
-/*****************************************
- * Code taken from the library OGLFT-0.9 *
- *                        Carlos Pereira *
- *****************************************/
-
-static void static_glu_begin (GLenum polygon)
-{ 
-glBegin (polygon);
-}
-
-static void static_glu_vertex (double* vertex)
-{
-glVertex3dv (vertex);
-}
-
-static void static_glu_end (void) 
-{
-glEnd ();
-}
-
-static void static_glu_combine (double coords[3], void* vertices[4], 
-float weights[4], void** output, gamgi_extruded* extruded)
-{
-double* vertex;
-
-/**************************************
- * pass vertex to OpenGL and save its *
- * address so it can be removed later *
- **************************************/
-
-vertex = (double *) malloc (3 * sizeof (double));
-gamgi_math_vector_copy (coords, vertex);
-*output = vertex;
-
-extruded->vertices = gamgi_engine_slist_add_start (extruded->vertices);
-extruded->vertices->data = vertex;
-}
-
-static void static_glu_error (GLenum error_code)
-{
-printf ("error during tessellation: %s\n", gluErrorString (error_code));
-}
-
-static int static_horizontal_move (FT_Vector* to, gamgi_extruded* extruded)
+int gamgi_mesa_text_horizontal_move (FT_Vector* to, gamgi_extruded* extruded)
 {
 if (extruded->open == TRUE) gluTessEndContour (extruded->tesselator);
 
@@ -404,7 +289,7 @@ extruded->open = TRUE;
 return 0;
 }
 
-static int static_horizontal_line (FT_Vector* to, gamgi_extruded* extruded)
+int gamgi_mesa_text_horizontal_line (FT_Vector* to, gamgi_extruded* extruded)
 {
 double* vertex;
 
@@ -436,7 +321,7 @@ return 0;
  * outline is fixed for all glyphs in the face.          *
  *********************************************************/
 
-static int static_horizontal_conic (FT_Vector* control, 
+int gamgi_mesa_text_horizontal_conic (FT_Vector* control, 
 FT_Vector* to, gamgi_extruded* extruded)
 {
 double* vertex;
@@ -524,7 +409,7 @@ return 0;
  * outline is fixed for all glyphs in the face.          *
  *********************************************************/
 
-static int static_horizontal_cubic (FT_Vector* control1, 
+int gamgi_mesa_text_horizontal_cubic (FT_Vector* control1, 
 FT_Vector* control2, FT_Vector* to, gamgi_extruded* extruded)
 {
 double* vertex;
@@ -622,7 +507,7 @@ extruded->last[2] = to_vertex[2];
 return 0;
 }
 
-static int static_vertical_move (FT_Vector* to, gamgi_extruded* extruded)
+int gamgi_mesa_text_vertical_move (FT_Vector* to, gamgi_extruded* extruded)
 {
 if (extruded->open == TRUE)
   {
@@ -644,7 +529,7 @@ extruded->open = TRUE;
 return 0;
 }
 
-static int static_vertical_line (FT_Vector* to, gamgi_extruded* extruded)
+int gamgi_mesa_text_vertical_line (FT_Vector* to, gamgi_extruded* extruded)
 {
 double vertex[2];
 double normal[2];
@@ -674,7 +559,7 @@ return 0;
  * outline is fixed for all glyphs in the face.          *
  *********************************************************/
 
-static int static_vertical_conic (FT_Vector* control, 
+int gamgi_mesa_text_vertical_conic (FT_Vector* control, 
 FT_Vector* to, gamgi_extruded* extruded)
 {
 double vertex[2];
@@ -749,7 +634,7 @@ return 0;
  * outline is fixed for all glyphs in the face.          *
  *********************************************************/
 
-static int static_vertical_cubic (FT_Vector* control1, 
+int gamgi_mesa_text_vertical_cubic (FT_Vector* control1, 
 FT_Vector* control2, FT_Vector* to, gamgi_extruded* extruded)
 {
 double vertex[2];
@@ -830,6 +715,104 @@ extruded->last[2] = 0.0;
 return 0;
 }
 
+/*****************************************************
+ * This routine draws extrusions with square ends,   *
+ * cut at 90 degrees to the length of the extrusion. *
+ *****************************************************/
+
+void static_extrusion (int n_contour, double *contour, double *normals, 
+double scale)
+{
+int i;
+double point[3]; 
+double norm[3]; 
+double depth;
+
+/**************************************************************
+ * the glyph z coordinate ranges between -depth/2 and depth/2 *
+ *                                                            *
+ *  z coordinates are independent of the face units per EM    *
+ **************************************************************/
+
+depth = GAMGI_MESA_EXTRUDED_DEPTH * GAMGI_MESA_EXTRUDED_SCALE;
+
+/**********************
+ * save graphic state *
+ **********************/
+
+glPushMatrix ();
+
+/***************************************
+ * draw all the lateral segments and   *
+ * connect back with the first segment *
+ ***************************************/
+
+norm [2] = 0.0;
+glBegin (GL_TRIANGLE_STRIP);
+for (i = 0; i <= n_contour; i++)
+  {
+  if (i == n_contour) i = n_contour = 0;
+
+  norm [0] = normals[2*i + 0];
+  norm [1] = normals[2*i + 1];
+  gamgi_math_vector_normal (norm);
+  glNormal3dv (norm);
+
+  point [0] = contour[2*i + 0] * scale;
+  point [1] = contour[2*i + 1] * scale;
+  point [2] = -depth / 2.0;
+  glVertex3dv (point);
+
+  point [2] = depth / 2.0;
+  glVertex3dv (point);
+  }
+glEnd ();
+
+/**********************************
+ * restore previous graphic state *
+ **********************************/
+
+glPopMatrix ();
+}
+
+static void static_glu_begin (GLenum polygon)
+{ 
+glBegin (polygon);
+}
+
+static void static_glu_vertex (double* vertex)
+{
+glVertex3dv (vertex);
+}
+
+static void static_glu_end (void) 
+{
+glEnd ();
+}
+
+static void static_glu_combine (double coords[3], void* vertices[4], 
+float weights[4], void** output, gamgi_extruded* extruded)
+{
+double* vertex;
+
+/**************************************
+ * pass vertex to OpenGL and save its *
+ * address so it can be removed later *
+ **************************************/
+
+vertex = (double *) malloc (3 * sizeof (double));
+gamgi_math_vector_copy (coords, vertex);
+*output = vertex;
+
+extruded->vertices = gamgi_engine_slist_add_start (extruded->vertices);
+extruded->vertices->data = vertex;
+}
+
+static void static_glu_error (GLenum error_code)
+{
+printf ("error during tessellation: %s\n", gluErrorString (error_code));
+}
+
 static void static_face (gamgi_extruded *extruded, 
 FT_OutlineGlyph glyph)
 {
@@ -1146,10 +1129,10 @@ extruded = (gamgi_extruded *) malloc (sizeof (gamgi_extruded));
  * polygons: lower and upper faces     *
  ***************************************/
 
-extruded->horizontal.move_to = (FT_Outline_MoveTo_Func) static_horizontal_move;
-extruded->horizontal.line_to = (FT_Outline_LineTo_Func) static_horizontal_line;
-extruded->horizontal.conic_to = (FT_Outline_ConicTo_Func) static_horizontal_conic;
-extruded->horizontal.cubic_to = (FT_Outline_CubicTo_Func) static_horizontal_cubic;
+extruded->horizontal.move_to = (FT_Outline_MoveTo_Func) gamgi_mesa_text_horizontal_move;
+extruded->horizontal.line_to = (FT_Outline_LineTo_Func) gamgi_mesa_text_horizontal_line;
+extruded->horizontal.conic_to = (FT_Outline_ConicTo_Func) gamgi_mesa_text_horizontal_conic;
+extruded->horizontal.cubic_to = (FT_Outline_CubicTo_Func) gamgi_mesa_text_horizontal_cubic;
 extruded->horizontal.shift = 0;
 extruded->horizontal.delta = 0;
 
@@ -1158,10 +1141,10 @@ extruded->horizontal.delta = 0;
  * polygons: lateral contour         *
  *************************************/
 
-extruded->vertical.move_to = (FT_Outline_MoveTo_Func) static_vertical_move;
-extruded->vertical.line_to = (FT_Outline_LineTo_Func) static_vertical_line;
-extruded->vertical.conic_to = (FT_Outline_ConicTo_Func) static_vertical_conic;
-extruded->vertical.cubic_to = (FT_Outline_CubicTo_Func) static_vertical_cubic;
+extruded->vertical.move_to = (FT_Outline_MoveTo_Func) gamgi_mesa_text_vertical_move;
+extruded->vertical.line_to = (FT_Outline_LineTo_Func) gamgi_mesa_text_vertical_line;
+extruded->vertical.conic_to = (FT_Outline_ConicTo_Func) gamgi_mesa_text_vertical_conic;
+extruded->vertical.cubic_to = (FT_Outline_CubicTo_Func) gamgi_mesa_text_vertical_cubic;
 extruded->vertical.shift = 0;
 extruded->vertical.delta = 0;
 
